@@ -15,10 +15,11 @@
 #'
 #' @export
 bed12_to_exons <- function(x) {
+  check_required(x)
   x <- check_interval(x)
 
   if (!ncol(x) == 12) {
-    stop("expected 12 column input", call. = FALSE)
+    cli::cli_abort("expected 12 column input")
   }
 
   res <- bed12toexons_impl(x)
