@@ -39,6 +39,11 @@
 #'
 #' @export
 bed_absdist <- function(x, y, genome) {
+
+  check_required(x)
+  check_required(y)
+  check_required(genome)
+
   x <- check_interval(x)
   y <- check_interval(y)
   genome <- check_genome(genome)
