@@ -20,7 +20,7 @@ create_introns <- function(x) {
   res <- mutate(
     res,
     .start = end, .end = lead(start),
-    score = ifelse(score == 1, 1, score - 1),
+    score = ifelse(strand == "+", score, score - 1),
     start = .start, end = .end
   )
   res <- select(res, -.start, -.end)
