@@ -1,11 +1,9 @@
-context("tbls")
-
 test_that("invalid column names throw error", {
   x <- tibble::tribble(
     ~pork, ~pie, ~hat,
     "chr1", 1, 50
   )
-  expect_error(check_interval(x), "expected 3 required names, missing: chrom, start, end")
+  expect_error(check_interval(x), "expected 3 required names, missing: chrom, start, and end")
 
   # missing 1 only
   x <- tibble::tribble(
@@ -20,7 +18,7 @@ test_that("invalid column names throw error", {
     ~foo, ~bar,
     "chr1", 1e4
   )
-  expect_error(check_genome(genome), "expected 2 required names, missing: chrom, size")
+  expect_error(check_genome(genome), "expected 2 required names, missing: chrom and size")
 })
 
 test_that("duplicate chromosomes refs throw error", {
@@ -35,7 +33,7 @@ test_that("duplicate chromosomes refs throw error", {
 test_that("gr_to_bed coerces GRanges objects", {
   skip_if_not_installed("GenomicRanges")
 
-  require(GenomicRanges)
+  suppressMessages(require(GenomicRanges))
   gr <- GRanges(
     seqnames = Rle(c("chr1", "chr2", "chr1", "chr3"), c(1, 3, 2, 4)),
     ranges = IRanges(1:10, end = 7:16, names = head(letters, 10)),
@@ -44,5 +42,5 @@ test_that("gr_to_bed coerces GRanges objects", {
 
   res <- gr_to_bed(gr)
   expect_silent(check_interval(res))
-  expect_is(res, "tbl_df")
+  expect_true("tbl_df" %in% class(res))
 })
